# Inputs

## song_path (from www.genius.com )
## songwithTime_path (from we sing)
## both are .txt file

# Outputs
# timestamp list

# Installation:
## pip install lyric_matcher

## t = lyricsmatcher(../lyrics_only_with_section.txt, ../lyrics_only_with_timestamp.txt)